@@ -1,33 +1,32 @@
 from __future__ import annotations
 
+import ast
 import filecmp
 import json
-import shlex
 import os
-import sys
-import requests
-from pathlib import Path
-from packaging.version import Version
-import shutil
-from tempfile import gettempdir
-
-import textwrap
-from typing import Any
-import click
 import re
+import shlex
+import shutil
+import sys
+import textwrap
 from concurrent.futures import Future, ThreadPoolExecutor, as_completed
+from pathlib import Path
+from tempfile import gettempdir
+from typing import Any
+
+import click
 import cloup
-from cloup.constraints import If, IsSet, accept_none, require_one
-from pyhelper_utils.shell import run_command
 import pytest
+import requests
+from cloup.constraints import If, IsSet, accept_none, require_one
+from jinja2 import DebugUndefined, Environment, FileSystemLoader, meta
+from packaging.version import Version
+from pyhelper_utils.shell import run_command
 from rich.console import Console
 from rich.syntax import Syntax
-
-from ocp_resources.resource import Resource
-
-from jinja2 import DebugUndefined, Environment, FileSystemLoader, meta
 from simple_logger.logger import get_logger
 
+from ocp_resources.resource import Resource
 
 SPEC_STR: str = "SPEC"
 FIELDS_STR: str = "FIELDS"
@@ -370,9 +369,18 @@ def parse_user_code_from_file(file_path: str) -> tuple[str, str]:
         _end_of_generated_code_index = data.index(end_of_generated_code_line)
         user_code = data[_end_of_generated_code_index + len(end_of_generated_code_line) :]
 
-    for _line in data.splitlines():
-        if _line.startswith("import") or _line.startswith("from"):
-            user_imports += f"{_line}\n"
+        tree = ast.parse(data)
+        imports = [imp for imp in tree.body if isinstance(imp, ast.Import) or isinstance(imp, ast.ImportFrom)]
+        splited_data = data.splitlines()
+
+        for _import in imports:
+            end_import_no = _import.end_lineno
+
+            if end_import_no and _import.lineno != end_import_no:
+                for num in range(_import.lineno - 1, end_import_no):
+                    user_imports += f"{splited_data[num]}\n"
+            else:
+                user_imports += f"{splited_data[_import.lineno - 1]}\n"
 
     return user_code, user_imports
 
@@ -615,6 +623,7 @@ def class_generator(
     output_dir: str = "",
     add_tests: bool = False,
     called_from_cli: bool = True,
+    update_schema_executed: bool = False,
 ) -> list[str]:
     """
     Generates a class for a given Kind.
@@ -622,12 +631,34 @@ def class_generator(
     LOGGER.info(f"Generating class for {kind}")
     kind = kind.lower()
     kind_and_namespaced_mappings = read_resources_mapping_file().get(kind)
-
     if not kind_and_namespaced_mappings:
-        LOGGER.error(f"{kind} not found in {RESOURCES_MAPPING_FILE}, Please run with --update-schema")
         if called_from_cli:
-            sys.exit(1)
+            if update_schema_executed:
+                LOGGER.error(f"{kind} not found in {RESOURCES_MAPPING_FILE} after update-schema executed.")
+                sys.exit(1)
+
+            run_update_schema = input(
+                f"{kind} not found in {RESOURCES_MAPPING_FILE}, Do you want to run --update-schema and retry? [Y/N]"
+            )
+            if run_update_schema.lower() == "n":
+                sys.exit(1)
+
+            elif run_update_schema.lower() == "y":
+                update_kind_schema()
+
+                class_generator(
+                    overwrite=overwrite,
+                    dry_run=dry_run,
+                    kind=kind,
+                    output_file=output_file,
+                    output_dir=output_dir,
+                    add_tests=add_tests,
+                    called_from_cli=True,
+                    update_schema_executed=True,
+                )
+
         else:
+            LOGGER.error(f"{kind} not found in {RESOURCES_MAPPING_FILE}, Please run --update-schema.")
             return []
 
     resources = parse_explain(kind=kind)
